@@ -3,6 +3,6 @@ rapid string matching library
 """
 __author__ = "Max Bachmann"
 __license__ = "MIT"
-__version__ = "0.13.0"
+__version__ = "0.13.2"
 
-from rapidfuzz import process, fuzz, utils# levenshtein
+from rapidfuzz import process, fuzz, utils, levenshtein
